@@ -1,5 +1,3 @@
-import six
-
 from .. import errors
 from ..constants import IS_WINDOWS_PLATFORM
 from ..utils import (
@@ -121,7 +119,7 @@ class ContainerSpec(dict):
                  privileges=None, isolation=None, init=None):
         self['Image'] = image
 
-        if isinstance(command, six.string_types):
+        if isinstance(command, str):
             command = split_command(command)
         self['Command'] = command
         self['Args'] = args
@@ -151,7 +149,7 @@ class ContainerSpec(dict):
         if mounts is not None:
             parsed_mounts = []
             for mount in mounts:
-                if isinstance(mount, six.string_types):
+                if isinstance(mount, str):
                     parsed_mounts.append(Mount.parse_mount_string(mount))
                 else:
                     # If mount already parsed
@@ -224,7 +222,7 @@ class Mount(dict):
         self['Source'] = source
         if type not in ('bind', 'volume', 'tmpfs', 'npipe'):
             raise errors.InvalidArgument(
-                'Unsupported mount type: "{}"'.format(type)
+                f'Unsupported mount type: "{type}"'
             )
         self['Type'] = type
         self['ReadOnly'] = read_only
@@ -260,7 +258,7 @@ class Mount(dict):
         elif type == 'tmpfs':
             tmpfs_opts = {}
             if tmpfs_mode:
-                if not isinstance(tmpfs_mode, six.integer_types):
+                if not isinstance(tmpfs_mode, int):
                     raise errors.InvalidArgument(
                         'tmpfs_mode must be an integer'
                     )
@@ -280,7 +278,7 @@ class Mount(dict):
         parts = string.split(':')
         if len(parts) > 3:
             raise errors.InvalidArgument(
-                'Invalid mount format "{0}"'.format(string)
+                f'Invalid mount format "{string}"'
             )
         if len(parts) == 1:
             return cls(target=parts[0], source=None)
@@ -347,7 +345,7 @@ def _convert_generic_resources_dict(generic_resources):
             ' (found {})'.format(type(generic_resources))
         )
     resources = []
-    for kind, value in six.iteritems(generic_resources):
+    for kind, value in generic_resources.items():
         resource_type = None
         if isinstance(value, int):
             resource_type = 'DiscreteResourceSpec'
@@ -443,7 +441,7 @@ class RollbackConfig(UpdateConfig):
     pass
 
 
-class RestartConditionTypesEnum(object):
+class RestartConditionTypesEnum:
     _values = (
         'none',
         'on-failure',
@@ -474,7 +472,7 @@ class RestartPolicy(dict):
                  max_attempts=0, window=0):
         if condition not in self.condition_types._values:
             raise TypeError(
-                'Invalid RestartPolicy condition {0}'.format(condition)
+                f'Invalid RestartPolicy condition {condition}'
             )
 
         self['Condition'] = condition
@@ -533,7 +531,7 @@ def convert_service_ports(ports):
         )
 
     result = []
-    for k, v in six.iteritems(ports):
+    for k, v in ports.items():
         port_spec = {
             'Protocol': 'tcp',
             'PublishedPort': k
